@@ -8,12 +8,13 @@ class OCIProvider(AbstractProvider):
     """
         Concrete implementation of the Oracle Cloud Infrastructure cloud provider.
     """
+    identifier = 'oci'
 
     def __init__(self, logger=None):
         self.logger = logger or logging.getLogger(__name__)
         self.vendor_file = '/sys/class/dmi/id/chassis_asset_tag'
 
-    def identify(self):
+    async def identify(self):
         """
             Tries to identify OCI using all the implemented options
         """
